package com.yiqi.core.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.core.domain.ClothSpeed;

/**
 * 洗衣速度Mapper接口
 *
 * @author xiaohei
 * @date 2023-08-20
 */
public interface ClothSpeedMapper extends BaseMapper<ClothSpeed> {
    /**
     * 查询洗衣速度
     *
     * @param id 洗衣速度主键
     * @return 洗衣速度
     */
    public ClothSpeed selectClothSpeedById(Long id);

    /**
     * 查询洗衣速度列表
     *
     * @param clothSpeed 洗衣速度
     * @return 洗衣速度集合
     */
    public List<ClothSpeed> selectClothSpeedList(ClothSpeed clothSpeed);

    /**
     * 新增洗衣速度
     *
     * @param clothSpeed 洗衣速度
     * @return 结果
     */
    public int insertClothSpeed(ClothSpeed clothSpeed);

    /**
     * 修改洗衣速度
     *
     * @param clothSpeed 洗衣速度
     * @return 结果
     */
    public int updateClothSpeed(ClothSpeed clothSpeed);

    /**
     * 删除洗衣速度
     *
     * @param id 洗衣速度主键
     * @return 结果
     */
    public int deleteClothSpeedById(Long id);

    /**
     * 批量删除洗衣速度
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteClothSpeedByIds(Long[] ids);
}
